==> haskell-openssl-streams-1.2.1.3-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-t7bNu7RlHtEIbnvJ0l2Fk
key: openssl-streams-1.2.1.3-t7bNu7RlHtEIbnvJ0l2Fk
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: c4e190394d0a26e7c567596e5139f90f
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.1/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-t7bNu7RlHtEIbnvJ0l2Fk
depends:
    HsOpenSSL-0.11.4.15-60yCX8QWwiPJJHJLYoNvVg base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-GecMReDhwXu2KpH81Ly9XL
    network-2.7.0.2-AhHTxdUIBGH70CptKdvDEL
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.1.3-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-Lw68pKnWo99Aa5gOd9lVTV
key: openssl-streams-1.2.1.3-Lw68pKnWo99Aa5gOd9lVTV
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 8378a13a8bedb157f24b940c391ec0ff
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.1/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-Lw68pKnWo99Aa5gOd9lVTV
depends:
    HsOpenSSL-0.11.4.15-GiBdEPPgZxG6GMfxeyDhfV base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-AAVyz4a7cll6ixTwZkniW9
    network-2.7.0.2-2yr2pvLPehY6oGeYQ5TSho
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
